@@ -338,6 +338,10 @@ The libSSH2 socket client
 
 The Parallels virtualization driver
 
+=item Sys::Virt::Error::FROM_LOCKSPACE
+
+The lockspace handling code
+
 =back
 
 =head2 ERROR CODE CONSTANTS
@@ -696,6 +700,10 @@ The operation is not supported on this host
 
 The SSH operation failed
 
+=item Sys::Virt::Error::ERR_RESOURCE_BUSY
+
+The resource requested is already in use
+
 =back
 
 =head1 AUTHORS
